SingleAppendOnlyProof

Struct SingleAppendOnlyProof 

pub struct SingleAppendOnlyProof {
    pub inserted: Vec<AzksElement>,
    pub unchanged_nodes: Vec<AzksElement>,
}
Proof that no leaves were deleted from the initial epoch. This means that unchanged_nodes should hash to the initial root hash and the vec of inserted is the set of leaves inserted between these epochs. If we built the tree using the nodes in inserted and the nodes in unchanged_nodes as the leaves with the correct epoch of insertion, it should result in the final root hash.

Fields

inserted: Vec<AzksElement>

The inserted nodes & digests

unchanged_nodes: Vec<AzksElement>

The unchanged nodes & digests