UpdateProof

Struct UpdateProof 

pub struct UpdateProof {
    pub epoch: u64,
    pub value: AkdValue,
    pub version: u64,
    pub existence_vrf_proof: Vec<u8>,
    pub existence_proof: MembershipProof,
    pub previous_version_vrf_proof: Option<Vec<u8>>,
    pub previous_version_proof: Option<MembershipProof>,
    pub commitment_nonce: Vec<u8>,
}
A vector of UpdateProofs are sent as the proof to a history query for a particular key. For each version of the value associated with the key, the verifier must check that:

  • the version was included in the claimed epoch,
  • the previous version was retired at this epoch,
  • the version did not exist prior to this epoch,
  • the next few versions (up until the next marker), did not exist at this epoch,
  • the future marker versions did not exist at this epoch.

Fields

epoch: u64

Epoch of this update

value: AkdValue

Value at this update

version: u64

Version at this update

existence_vrf_proof: Vec<u8>

VRF proof for the label for the current version

existence_proof: MembershipProof

Membership proof to show that the key was included in this epoch

previous_version_vrf_proof: Option<Vec<u8>>

VRF proof for the label for the previous version which became stale

previous_version_proof: Option<MembershipProof>

Proof that previous value was set to old at this epoch

commitment_nonce: Vec<u8>

Nonce for commitment value derived from raw AkdLabel and AkdValue